@@ -25,11 +25,9 @@ class AttrStateMixin(TransformMixin, InspectionMixin):
         res = {}
         inspections = self.get_inspections()["all_by_key"]
         for k, v in self.get_attr_changes().items():
-            # (type_, key, info, col)
-            info = inspections[k][2]
-            col = inspections[k][3]
-            res[self.export_column_name(k, info)] = (
-                self.export_value(col, v[0]),
-                self.export_value(col, v[1]),
+            ic = inspections[k]
+            res[self.export_column_name(k, ic.info)] = (
+                self.export_value(ic.column, v[0]),
+                self.export_value(ic.column, v[1]),
             )
         return res
