@@ -10,7 +10,6 @@ class InspectedColumn(NamedTuple):
     key: str
     info: dict
     column: Any
-    original_column: Any
 
 
 class InspectionMixin:
@@ -58,8 +57,7 @@ class InspectionMixin:
                 type=cc_type,
                 key=cls.get_column_key(c),
                 info=cls.get_column_info(c),
-                column=getattr(cls, k),
-                original_column=c,
+                column=c,
             )
             res[cc_type].append(ic)
             res["all"].append(ic)
