@@ -21,7 +21,7 @@ class OrderingMixin(TransformMixin, AccessControlMixin):
     @classmethod
     def create_sort_criteria(cls, sort_columns):
         valid_columns = {
-            cls.export_column_name(ic.key, ic.info): ic.column
+            cls.export_column_name(ic.key, ic.info): getattr(cls, ic.key)
             for ic in cls.get_readables()
             if ic.type != "relationships"
         }
